#
# spec file for package python-ldappool
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-ldappool
Version:        2.4.1
Release:        bp153.1.15
Summary:        A connection pool for python-ldap
License:        MPL-1.1 OR GPL-2.0-or-later OR LGPL-2.1-or-later
Group:          Development/Languages/Python
URL:            https://git.openstack.org/cgit/openstack/ldappool
Source:         https://files.pythonhosted.org/packages/source/l/ldappool/ldappool-%{version}.tar.gz
BuildRequires:  %{python_module ldap >= 3.0.0}
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module stestr}
BuildRequires:  %{python_module testresources}
BuildRequires:  %{python_module testtools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PrettyTable
Requires:       python-ldap >= 3.0.0
BuildArch:      noarch
%python_subpackages

%description
A simple connector pool for python-ldap.

The pool keeps LDAP connectors alive and let you reuse them,
drastically reducing the time spent to initiate a ldap connection.

The pool has useful features like:

- transparent reconnection on failures or server restarts
- configurable pool size and connectors timeouts
- configurable max lifetime for connectors
- a context manager to simplify acquiring and releasing a connector

%prep
%setup -q -n ldappool-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec -m stestr.cli run

%files %{python_files}
%doc CHANGES.rst README.rst
%{python_sitelib}/*

%changelog
* Thu Mar 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.4.1:
  * Various release notes and docu updates
* Mon Dec 10 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 2.4.0:
  * Allow pool status to be printed as a table
  * Add plumbing to support reno release notes
  * Handle retry logic for timeouts with multiple LDAP servers
  * Improve connection retry logging
  * PY3: switch to using unicode text values
  * Don't quote {posargs} in tox.ini
  * Removed older version of python added 3.5
  * add python 3.6 unit test job
  * import zuul job settings from project-config
  * fix tox python3 overrides
  * fix ldappool bad password retry logic
  * Add author email to setup.cfg
  * Switch to python-ldap again
  * Bump to hacking 1.1.x
  * Switch to stestr
  * add lower-constraints job
  * Updated from global requirements
  * Avoid tox\_install.sh for constraints support
  * Turn on warning-is-error for sphinx build
  * Switch from oslosphinx to openstackdocstheme
  * Fix html\_last\_updated\_fmt for Python3
- Update URL
* Thu Aug 24 2017 tbechtold@suse.com
- update to 2.1.0
  * Updated from global requirements
  * Don't call start\_tls\_s() twice
  * [Fix gate]Update test requirement
  * Add Constraints support
  * update README to reflect actual ldap dependency
  * Expose SERVER\_DOWN if connection fails
- convert to singlespec
* Wed May 18 2016 dmueller@suse.com
- update to 2.0.0:
  * Add py3 info to setup.cfg
  * Updated from global requirements
  * make ldappool py3 compatible
  * use standard docstring convention for parameters
  * Use standard-library logging to record errors
  * Raise an explicit BackendError on TLS failures
  * Fix pool_full race condition
  * additional files to ignore in .gitignore
  * Fix license in setup.py
  * add .gitreview and fix ldappool gate
  * Add test-requirements for py27 testing
  * PEP8 fixes
  * Add support for tox unit testing
  * Initialize conn in _create_connector (fixes: #7)
  * Use setuptools when available
  * #4: UTF-8 encode passwd only when set
* Wed Feb  4 2015 dmueller@suse.com
- fix license
* Mon Jan 19 2015 rhafer@suse.com
- Initial package. Version 1.0
